@@ -106,7 +106,7 @@ class Block(ABC):
 
     def __get_standard_matrix_row(self, n_blocks):
 
-        # This Methods returns the row of the Cost Matrix corresponding to the current block in a block-oriented
+        # These Methods returns the row of the Cost Matrix corresponding to the current block in a block-oriented
         # computation scheme
 
         # The Cost Matrix is a squared matrix of size NXN where N is the number of blocks. Another column,
@@ -1316,8 +1316,9 @@ class ArrayHandler:
         self.vector = np.zeros(0)
 
         self.modules_handler = ModulesHandler()
-
+        self.matrix_analyzer = None
         self.pf_diagram = None
+
         self.options = CalculationOptions()
 
     # -------------------------------------
@@ -1326,7 +1327,7 @@ class ArrayHandler:
 
     def calculate(self):
 
-        # This methods generate the cost matrix combining the lines returned by each block and then solve it. Before
+        # These methods generate the cost matrix combining the lines returned by each block and then solve it. Before
         # doing so, it invokes the method "__prepare_system" that prepares the system to be solved asking the
         # blocks to generate their own support blocks (if needed) and appending them to the block list.
 
@@ -1374,9 +1375,9 @@ class ArrayHandler:
 
                     i += 1
 
-                matrix_analyzer = MatrixAnalyzer(self.matrix, self.vector)
-                matrix_analyzer.solve()
-                sol = matrix_analyzer.solution
+                self.matrix_analyzer = MatrixAnalyzer(self.matrix, self.vector)
+                self.matrix_analyzer.solve()
+                sol = self.matrix_analyzer.solution
 
                 self.append_solution(sol)
                 self.calculate_coefficients()
@@ -1424,7 +1425,17 @@ class ArrayHandler:
 
             except:
 
-                self.options.calculate_component_decomposition = False
+                try:
+
+                    __inverse_matrix = self.matrix_analyzer.inverse_matrix
+
+                    for block in self.block_list:
+
+                        block.generate_output_cost_decomposition(__inverse_matrix[block.ID, ])
+
+                except:
+
+                    self.options.calculate_component_decomposition = False
 
     def prepare_system(self):
 
